==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/obj_listbox_checked.js <==
_me = obj_listbox_checked.prototype;
function obj_listbox_checked(){};

_me.__constructor = function(){
	var me = this;

	this.__idTable = [];
	this.__value;

	this._main.onclick = function(e){
		var e = e || window.event;
		var elm = e.target || e.srcElement;

		var id;
		switch(elm.tagName.toLowerCase()){
		case 'input':
			var elm2 = searchParent(elm,'tr');
            id = elm2.id.substr(me._pathName.length+1);
            var key = inArray(me.__idTable,id), check;
            if (key<0) return;
            
			me.__aData[key].checked = elm.checked;
            
			if (me._oncheck) me._oncheck(e,key,elm.checked);
			me.__exeEvent('oncheck',e,{"owner":me,"key":key,"checked":elm.checked});
			
			break;

		case 'td':
			elm = searchParent(elm,'tr');

		case 'tr':
			id = elm.id.substr(me._pathName.length+1);
			me._value(me.__idTable[id]);
		}

		if (me._onclick) me._onclick(e);
		me.__exeEvent('onclick',e,{"owner":me});
	};
	
	this._main.ondblclick = function(e){
		var e = e || window.event;
		var elm = e.target || e.srcElement;

		switch(elm.tagName.toLowerCase()){
		case 'td':
		case 'tr':
			if (me._ondblclick) me._ondblclick(e);
			me.__exeEvent('ondblclick',e,{"owner":me});
		}
	};
};

_me._value = function(v){
	//GET
	if (typeof v == 'undefined')
		return [this.__value];

	if (typeof v == 'object')
		for(var i in v){
			v  = v[i];
			break;
		}
	
	//SET
	if (typeof v == 'undefined' || this.__value == v) return;
	
	if (typeof this.__value == 'string'){
		var key = inArray(this.__idTable,this.__value);
		if (key>-1){
			var elm = document.getElementById(this._pathName+'/'+key);
			if (elm)
				removecss(elm,'active');
		}
	}
	
	var key = inArray(this.__idTable,v);
	if (key>-1){
		var elm = document.getElementById(this._pathName+'/'+key);
		if (elm){
			this.__value = v.toString();
			addcss(elm,'active');
		}
	}
};

/**
 * aData.checked
 *      .css
 *      .title
 **/
_me._fill = function(aData){

//inspect2(aData);

	if (aData) this.__aData = aData;
	
	var id = 0,str = ['<table>'];
	
	this.__idTable = [];
	
	for(var i in this.__aData){
		this.__idTable.push(i.toString());
		id = this.__idTable.length-1;
		str.push(
		'<tr id="'+this._pathName+'/'+id+'"'+(typeof this.__value!= 'undefined' && this.__value == i?' class="active"':'')+'>'+
		'<th><input type="checkbox"'+ (this.__aData[i].checked>0?' checked':'') +'/></th>'+
		'<td'+ (this.__aData[i].css?' class="'+ this.__aData[i].css +'"':'') +'>'+ (this.__aData[i].title?this.__aData[i].title.escapeHTML():'') +'</td>'+
		'</tr>');
	}
	str.push('</table>');

	this._main.innerHTML = str.join("\n");
};

	_me.__update = function (sDataSet){
		if (!sDataSet) return;

		if (this._listener == sDataSet)
			this._value(dataSet.get(this._listener,this._listenerPath));
		else
		if (this._listener_data == sDataSet)
		    this._fill(dataSet.get(this._listener_data,this._listenerPath_data));
	};

	_me._listen_data = function(sDataSet,aDataPath){
		this._listener_data = sDataSet;
		if (typeof aDataPath == 'object') this._listenerPath_data = aDataPath;
		dataSet.obey(this,'_listener_data',sDataSet);
	};

==> IceWarpServer-10.1.4_RHEL5.tar.gz: html/webmail/client/inc/obj_listbox_checked.js <==
_me = obj_listbox_checked.prototype;
function obj_listbox_checked(){};

_me.__constructor = function(){
	var me = this;

	this.__idTable = [];
	this.__value;

	this._main.onclick = function(e){
		var e = e || window.event;
		var elm = e.target || e.srcElement;

		var id;
		switch(elm.tagName.toLowerCase()){
		case 'input':
			var elm2 = searchParent(elm,'tr');
            id = elm2.id.substr(me._pathName.length+1);
            var key = me.__idTable[id], check;

			if (key<0) return;
            
			me.__aData[key].checked = elm.checked;
            
			if (me._oncheck) me._oncheck(e,key,elm.checked);
			me.__exeEvent('oncheck',e,{"owner":me,"key":key,"checked":elm.checked});
			
			break;

		case 'td':
			elm = searchParent(elm,'tr');

		case 'tr':
			id = elm.id.substr(me._pathName.length+1);
			me._value(me.__idTable[id]);

			if (me._onclick) me._onclick(e);
			me.__exeEvent('onclick',e,{"owner":me});
		}
	};
	
	this._main.ondblclick = function(e){
		var e = e || window.event;
		var elm = e.target || e.srcElement;

		switch(elm.tagName.toLowerCase()){
		case 'td':
		case 'tr':
			if (me._ondblclick) me._ondblclick(e);
			me.__exeEvent('ondblclick',e,{"owner":me});
		}
	};
};

_me._value = function(v){

	//GET
	if (typeof v == 'undefined')
		return this.__value?[this.__value]:[];

	//SET
	if (typeof v == 'object')
		for(var i in v){
			v  = v[i];
			break;
		}

	if (this.__value == v) return;
	
	if (typeof this.__value != 'undefined'){
		var elm,key = inArray(this.__idTable,this.__value);
		if (key>-1 && (elm = document.getElementById(this._pathName+'/'+key)))
			removecss(elm,'active');
	}

    if (typeof v != 'undefined'){
		var key = inArray(this.__idTable,v);
		if (key>-1){
			var elm = document.getElementById(this._pathName+'/'+key);
			if (elm){
				this.__value = v.toString();
				addcss(elm,'active');
			}
		}
	}
	else
    	delete this.__value;
};

/**
 * aData.checked
 *      .css
 *      .title
 **/
_me._fill = function(aData){

	if (aData) this.__aData = aData;
	
	var id = 0,str = ['<table>'];
	
	this.__idTable = [];
	
	for(var i in this.__aData){
		this.__idTable.push(i.toString());
		id = this.__idTable.length-1;
		str.push(
		'<tr id="'+this._pathName+'/'+id+'"'+(typeof this.__value!= 'undefined' && this.__value == i?' class="active"':'')+'>'+
		'<th><input type="checkbox"'+ (this.__aData[i].checked>0?' checked':'') +'/></th>'+
		'<td'+ (this.__aData[i].css?' class="'+ this.__aData[i].css +'"':'') +'>'+ (this.__aData[i].title?this.__aData[i].title.escapeHTML():'') +'</td>'+
		'</tr>');
	}
	str.push('</table>');

	this._main.innerHTML = str.join("\n");
};

	_me.__update = function (sDataSet){
		if (!sDataSet) return;

		if (this._listener == sDataSet)
			this._value(dataSet.get(this._listener,this._listenerPath));
		else
		if (this._listener_data == sDataSet)
		    this._fill(dataSet.get(this._listener_data,this._listenerPath_data));
	};

	_me._listen_data = function(sDataSet,aDataPath){
		this._listener_data = sDataSet;
		if (typeof aDataPath == 'object') this._listenerPath_data = aDataPath;
		dataSet.obey(this,'_listener_data',sDataSet);
	};
